Parameters

Struct Parameters 

pub struct Parameters { /* private fields */ }
Information about the parameters a Floe session is using.

Implementations

Source

impl Parameters

pub const LENGTH: usize = 10

The length of the parameter info in the header, in bytes.

pub fn aead_id(&self) -> u8

Get the unique ID of the AEAD that is used for this Floe session.

pub fn kdf_id(&self) -> u8

Get the unique ID of the KDF implementation that is used for this Floe session.

pub fn segment_length(&self) -> u32

Get configured segment length of this Floe session.

pub fn floe_iv_size(&self) -> u32

Get the size of the Floe initialization vector of this Floe session.