pub struct Parameters { /* private fields */ }Expand description
Information about the parameters a Floe session is using.
Implementations
Sourceimpl Parameters
impl Parameters
Sourcepub fn kdf_id(&self) -> u8
pub fn kdf_id(&self) -> u8
Get the unique ID of the KDF implementation that is used for this Floe session.
Sourcepub fn segment_length(&self) -> u32
pub fn segment_length(&self) -> u32
Get configured segment length of this Floe session.
Sourcepub fn floe_iv_size(&self) -> u32
pub fn floe_iv_size(&self) -> u32
Get the size of the Floe initialization vector of this Floe session.